@@ -24,10 +24,12 @@
 #define __GDICT_COMMON_H__
 
 #include <gtk/gtk.h>
+#include <gconf/gconf-client.h>
 
 G_BEGIN_DECLS
 
-gboolean gdict_create_data_dir    (void);
+gboolean gdict_create_data_dir (void);
+gchar *  gdict_get_data_dir    (void) G_GNUC_MALLOC;
 
 void     gdict_show_error_dialog  (GtkWindow   *parent,
 				   const gchar *message,
@@ -36,6 +38,11 @@ void     gdict_show_gerror_dialog (GtkWindow   *parent,
 				   const gchar *message,
 				   GError      *error);
 
+gchar *  gdict_gconf_get_string_with_default (GConfClient *client,
+					      const gchar *key,
+					      const gchar *def);
+
+
 G_END_DECLS
 
 #endif /* __GDICT_COMMON_H__ */
